
# ========================
# ACP en R avec FactoMineR
# ========================

# Exemple d'analyse en composantes principales (ACP), avec les donnes "food.txt" (Birks 87)
# de prfrences alimentaires relatives  20 aliments pour 16 pays d'Europe en 1987

foodr = read.table("food.txt", header=TRUE, row.names="pays") # la colonne "pays" est l'identifiant

foodr # pour voir...

fix(foodr) # si on veut "diter" les donnes; la suite du script ne peut s'excuter que
# lorsque l'diteur est referm
 
# Pour faire l'ACP, on utilise la procdure "PCA" du package "FactoMineR", qu'il convient
# donc de charger pralablement

# Attention "PCA" en majuscule ! (c'est le choix des auteurs de FactoMineR)

library(FactoMineR) # pour charger le package "FactoMineR" suppos dj install
# alternative par script  la commande "Charger le package..." du menu "Packages"

help(PCA) # si on veut lire l'aide de la commande "PCA"

acpfood = PCA(foodr, scale.unit=FALSE) # ici ACP non norme et plan 1-2

plot.PCA(acpfood, axes=c(2,3)) # si on veut le plan 2-3 (procdure "plot.PCA" du package)
plot.PCA(acpfood, axes=c(2,3), choix="var") # idem pour les variables

# Et pour les rsultats numriques

acpfood$eig # les valeurs propres, ou taux d'inertie, successives ("eigenvalues")
acpfood$ind # ce qui concerne les individus
acpfood$ind$coord # seulement les composantes principales (ou nouvelles coordonnes)
acpfood$var # les variables

# On peut sauvegarder les composantes principales, par exemple, dans un fichier externe
write.table(acpfood$ind$coord, file="acpres.txt")
# ou write.table(acpfood$ind$coord, file="acpres.txt", sep=";", dec=",") si ncessaire
# ou encore pour un fichier "csv" directement lisible par Excel
write.table(acpfood$ind$coord, file="acpres.csv", sep=",", col.names=NA, qmethod = "double")

acpfood2 = PCA(foodr, scale.unit=FALSE, ind.sup=15:16) # avec GB et IRE en supplmentaires
# ou aussi bien "ind.sup=c(15,16)", utile si ces lignes n'avaient pas t conscutives

plot.PCA(acpfood2, axes=c(2,3))
plot.PCA(acpfood2, axes=c(2,3), choix="var")

acpfood2$eig
acpfood2$ind
acpfood2$ind.sup # ce qui concerne les individus supplmentaires
acpfood2$var

